function [data] = AR_coupling2(cfg, data, t)

%  This function calculates two AR time series X and Y with X->Y coupling, also with M. Linder's code

order    = cfg.order;           % AR order
nSamples = cfg.nS;        % samples per trial
eta_x    = cfg.eta_x ;          % strength of the innovation term for the AR process in x
eta_y    = cfg.eta_y ;          % strength of the innovation term for the AR process in y

theta_x  = cfg.x_noise ;          % strength of the noise signal added to x
theta_y  = cfg.y_noise ;          % strength of the noise signal added to y

coupling = cfg.coupling;        % type of x->y coupling

gamma    = cfg.gamma;           % coupling strength

fsample  = data.fsample;        % samples per second                         
dt       = cfg.dt;              % coupling delay in samples

if isfield(cfg,'phi_0')
    phi_0    = cfg.phi_0;       % relative size of AR parameters
else
    phi_0    = 0.2;  
end
    
if isfield(cfg,'mode')
    mode = cfg.mode;            % mode of series generation 'Felix' or 'Michael'
else
    mode = 'Felix';
end

if isfield(cfg,'nlf')           % non-linearity factor
    nlf  = cfg.nlf;
else
    nlf  = 1; 
end
    
    
if strcmp(mode, 'Felix')
%% preallocation and generation of start values and parameters -  Felix

for i = 1:nSamples+3000
    x = 0;
    y = 0;
end

goon = true;

while goon==true
    
    %%%% generate random start values and parameters
     
    for i = 1:order                            
        
        x(i) = randn;
        y(i) = randn;
       % x(i) = rand(1)-0.5;                     % generate random start values for x
      %  y(i) = rand(1)-0.5;                     % generate random start values for y
        par_x(i) = phi_0*(rand(1)-0.5);             % generate random parameters for x
        par_y(i) = phi_0*(rand(1)-0.5);             % generate random parameters for y
    end;
    
    %%%% check if stationary
    
    coef_x(1)=1;
    coef_y(1)=1;
    coef_x(2:order+1)=par_x;
    coef_y(2:order+1)=par_y;
    
    roots_xy(1:order,1) = roots(coef_x);
    roots_xy(1:order,2) = roots(coef_y);
    
    abso(1:order,1) = abs(roots(coef_x));
    abso(1:order,2) = abs(roots(coef_y));
    
    
    if isempty(find(abso>=1,1))                             %#ok<EFIND>
        goon = false;
    else
        display('WS stationarity not fulfilled, generating new AR parameters')
    end
    
end

% display(x);
% display(y);
% display(par_x);
% display(par_y);
% 
% abso

b1=0;
b2=50;



%% calculate x series                   - Felix

for a = (order+1):nSamples+3000                  
    x(a) = 0;                            
    
    for o = 1:order     
        x(a) = x(a) + par_x(o)*x(a-o);           % AR processing
    end
    
     x(a) = x(a) + eta_x*randn;               % add innovation term
     x2(a)= x(a)^2;                              % calculate x^2
     xt(a) = 1/(1+exp(b1+b2*x(a)));              % calculate treshold function
    
end

x(1:1500) =[];                                   % cut off first 1500 samples from x series 
x2(1:1500)=[];                                   % cut off first 1500 samples from x2 series 
xt(1:1500)=[];                                   % cut off first 1500 samples from xt series 

var_x    = var(x);
var_x2   = var(x2);
var_xt   = var(xt);

switch coupling 
    
    case 'lin'
        xfun  = x;
        
    case 'quad'
        xfun  = x2;
        gamma = gamma*sqrt(var_x/var_x^2);
        
    case 'tresh'
        xfun = xt;
         
    case 'mod'
        xfun = x;
        gamma = gamma*sqrt(var_x/var_x^2);
              
end

%% calculate y series           - Felix

for a = (order+1):size(x,2)                    
    y(a) = 0;                               

    for o = 1:order
        y(a) = y(a) + par_y(o)*y(a-o);              % AR processing  
    end
    
    if (a>dt)
        if strcmp(coupling,'mod')
            y(a) = y(a) + gamma*xfun(a-dt)*y(a-1);  % add coupling 
        else
            y(a) = y(a) + gamma*xfun(a-dt);         % add coupling lin, quad or tresh
        end
    end
    
    y(a) = y(a) + eta_y*randn;                   % add innovation term
        
end


x(1:1500) = [];                                     % cut off first 1500 samples from x series 
y(1:1500) = [];                                     % cut off first 1500 samples from y series 

%% normalize and add noise     - Felix
                                 

var_x = var(x);
var_y = var(y);
data.gamma = gamma;


for a = 1:size(x,2)  
    x(a)  =  x(a)/sqrt(var_x);                              % normalize x series    
end

for a = 1:size(y,2)  
    y(a)  =  y(a)/sqrt(var_y);                              % normalize y series
end

for i=1:nSamples
    x(i)=x(i) + theta_x*randn(1)-0.5;                         % add noise to x series
end

for i=1:nSamples
    y(i)=y(i) + theta_y*randn(1)-0.5;                         % add noise to y series
end




var_x = var(x);
var_y = var(y);

for a = 1:size(x,2)  
    x(a)  =  x(a)/sqrt(var_x);                              % normalize x series    
end

for a = 1:size(y,2)  
    y(a)  =  y(a)/sqrt(var_y);                              % normalize y series
end

for a = 1:size(x,2)  
    time(a)    = a/fsample;
end;

end;                                                        %% end Felix' data generation




if strcmp(mode,'Michael')
%% Michael Lindner's version:


for iii = 1:1000000
    %epsilon = rand;
    c = 0.1*rand(1,order);
    %c = c-0.5*epsilon;
    sc=sum(c);
    if abs(sc)<=1 && abs(sc)>= .85
        break
    end
end



for k=1:max(order,dt)+1    % first points of the signals (up to the Markov order)
    x(k)=randn;
    y(k)=randn;
end



for i=max(order,dt)+1:nSamples+999+k   % following points can now be iterated
    
    history_x=0.0;
    for p=0:order-1   % history incorporating the last order points (to include different parameters values let alpha be a function of p; alpha(p), i.e. a vector)
        history_x = history_x+c(p+1)*x(i-p);
    end
    
    history_y=0.0;
    for p=0:order-1   % history incorporating the last order points (to include different parameters values let alpha be a function of p; alpha(p), i.e. a vector)
        history_y = history_y+c(p+1)*y(i-p);
    end
    
    
    x(i+1)=history_x+eta_x*randn;
    
    y(i+1)=history_y+nlf*gamma*x(i-dt)^2+eta_y*randn;
    
end

% ts1(:,j)=X(k+1:end);
% ts2(:,j)=Y(k+1:end);


x(1:k) = [];
y(1:k) = [];

        
for a = 1:nSamples  
    time(a)    = a/fsample;
end;

x=x(1001:nSamples+1000);
r1 = randn(1,nSamples);

var_x=mean(var(x));
var_r1=mean(var(r1));

rc1 = r1*theta_x*(var_x/var_r1)^.5;

x=10*(x+rc1);


y=y(1001:nSamples+1000);         
r2 = randn(1,nSamples);

var_y=mean(var(y));
var_r2=mean(var(r2));

rc2 = r2*theta_y*(var_y/var_r2)^.5;

y=10*(y+rc2);

end                                                     %% end Michael's data gen.



%% plot
% 
% figure();
% 
% subplot(2,1,1)   
% plot(x) ,   xlabel ('x, normalisiert'),   axis ([0 nSamples -10 10])   
% 
% subplot(2,1,2) 
% plot(y) ,   xlabel('y,  normalisiert'),   axis ([0 nSamples -10 10])  

for i=1:5
    display('');
end;


%% append trial to data

xy(1,1:nSamples) = x;
xy(2,1:nSamples) = y;

data.trial{t} = xy;
data.time{t}  = time; 

