function [filename] = TE_coupling(cfg_in,par)

 % This function calculates the TE for X->Y coupling of AR processes.
 % This version of TE_coupling adds noise on y
 
for r = cfg_in.srun:cfg_in.n_runs   
    %% calculation of AR series
    
%     cfg = [];
%     cfg.order    = 10;                  % AR order
%     cfg.nTrials  = nT;                  % number of trials
%     cfg.nSamples = nS;                  % samples per trial
%     cfg.eta_x    = 1;                   % strength of the innovation term for the AR process in x
%     cfg.eta_y    = 1;                   % strength of the innovation term for the AR process in y
%     
%     cfg.x_noise  = x_noise;              % strength of the noise signal that is laid on top of the x series
%     cfg.y_noise  = y_noise;              % strength of the noise signal that is laid on top of the y series
%     
%     cfg.coupling = cpl;                 % type of x->y coupling, "lin' or 'quad'
%     
%     cfg.gamma    = gamma;               % coupling strength
%     cfg.dt       = 20;                  % coupling delay in samples
% 

    cfg = cfg_in;
    para = cfg_in;  
    para.phi_0 = 0.2;
    toi          = cfg.toi;
    u            = cfg.u;
   
    data.fsample = cfg.fsample;                 % sampling rate
    
    data.label{1,1}='x';
    data.label{2,1}='y';
    
    cd('/data/projects/TransferEntropy/AR_simulations/');
    
    for t = 1:cfg.nTrials
        
        data = AR_coupling2(cfg,data,t);       % calculate x and y series
        
    end
%     
%     h = figure()
%     
%     for t = 1:24
%         if mod(t,8) < 5 && mod(t,8) ~= 0
%             t
%          subplot(6,4,t)   
%               plot(data.trial{t}(1,:)), axis([0 cfg.nSamples -5 5 ])     
%          subplot(6,4,t+4) 
%               plot(data.trial{t}(2,:)), axis([0 cfg.nSamples -5 5 ]) 
%         end
%     end
    
    
    savepath = cfg.path;
    
    g_str  = sprintf('%1.1f',cfg.gamma);
    nx_str = sprintf('%1.1f',cfg.x_noise);
    ny_str = sprintf('%1.1f',cfg.y_noise);
    u_str  = sprintf('%02d',cfg.u);
    if mod(cfg.u,1) ~= 0
        u_str  = sprintf('%02.1f',cfg.u);
    end
    r_str  = sprintf('%02d',r);
    T_str  = sprintf('%02d',cfg.nTrials);
    filename = strcat(cfg.coupling,'_g',g_str,'_nx',nx_str,'_ny',ny_str,'_u',u_str,'_r',r_str);
    
    
     filename = strcat(filename, '_nT',T_str)
    
    u
    %% TE calculation

    cfg=[];
    cfg.channel          = data.label;      % a cell array with the names of the channels to analyze. here all channels in the dataset are analyzed
    cfg.toi              = [0 toi];           % the time interval of interest in secs
    cfg.Path2TSTOOL      = '/data/common/OpenTSTOOL_v1-2'; % the path of the TStool toolbox
    
    if strcmp(cfg_in.opt_meth,'ragwitz')
        
        cfg.ragdim       = [1:10];     % range of embedding dimensions to scan vector (1xnumdim)
        cfg.ragtaurange  = [1 2.0];
        cfg.ragtausteps  = 5;
        
        cfg.flagNei = 'Mass';
        cfg.sizeNei =  cfg_in.sizeNei;    !!!    % Radius or mass for the neighbor search according to flagNeighborhood
        cfg.repPred =  cfg_in.nS;          % repPred represents # of points for which the prediction is performed 
                                          % (it has to be smaller than length(timeSeries)-(dimEmb-1)*tauEmb-u)
                  
    else            % use cao
        
            
         cfg.optimizemethod   ='cao';       % select the CAO method to estimate embedding dimensions
         cfg.caodim           = 1:8;        % check dimensions between 1 and 8;
         cfg.tau              = 1.5;        % embedding delay in units of act (x*act)   (default = 1.5)
               
                                               % always choose bigger values when in doubt - also see Vicente 2010 
 
          cfg.caokth_neighbors = cfg_in.sizeNei;        % number of neighbors for fixed mass search
          cfg.kth_neighbors   = 4;         % number of neighbors for fixed mass search (controls  balance of bias/statistical errors)
         % cfg.TheilerT        = act;   
    
    end
    
    u
    cfg.predicttime_u    = u;           % the prediction time im ms (e.g. the axonal delay; 
    cfg.trialselect      = 'ACT' ;      % ACT threshholding of trials - 'ACT' ,'range' or 'no'  (default = 'ACT')
    cfg.actthrvalue      = 150;         % Do not accept trials that have a longer autocorrelation decay time (ACT) than this (helps to avoid 'out of data' errors)
    cfg.minnrtrials      = 15;          % abort calculations if we do not have at least this number of trials with acceptable ACT
    
          %         if you chose 'range':
          %                 cfg.trial_from  = Inferior limit for the trials to be considered
          %                 cfg.trial_to    = Superior limit for the trials to be considered
          %                 cfg.maxlag      = the range of lags for computing the auto correlation time: from -MAXLAG to MAXLAG (default = 1000)
    
        u  
    cfg.feedback         = 'no';       % ???
   
    repeat = 1;
    
    while repeat
        try
            repeat = 0;
            data = TEprepare(cfg,data);           % the actual command that prepares the data for subsequent TE analysis
                       
            u
            
            cfg2 = [];
            cfg2.par = para;                         % write the parameters for the AR calculations
            cfg2.surrogatetype = 'trialshuffling';   % the type of surrogates that are created for significance testing
            cfg2.shifttesttype='TEshift>TE';         % the type of shift test that is used (Vicente, J Comp Neursci, 2010 and Wibral, Prog Biophys Mol Biol, 2010)
            cfg2.fileidout = strcat(savepath, filename);   % a prefix for the results filename
            TEsurrogatestats(cfg2,data);             % the actual command that computes transfer entropy for the original data, the surrogate data, and the shifttest data and that performs the statistical test.
            
            u
            
        catch ME
            display(ME.message);
            if strcmp(cfg_in.opt_meth,'ragwitz') && cfg.repPred>300
                cfg.repPred = cfg.repPred-100;
                rP_str = sprintf('%d',cfg.repPred);
                msg = strcat('Setting # of points for prediction to: ',rP_str);
                display(msg);
                repeat = 1;
            else 
                
            end
        end
    end
    
    
    
    out_str = strcat('Finished run ',r_str);
    display(out_str);
    
end
msg_out = strcat('Files saved in: ', savepath);
disp(msg_out);
cfg = [];
cfg = cfg_in;
