function [] = make_fig(par, values, plotpar)

% This function plots TE p-values and significance test results

plotpar.boxtext=make_text(par);

if plotpar.plot_pval
    plot_pval(par, values, plotpar)
end

if plotpar.plot_sign
    plot_sign(par, values, plotpar)
end



end
    
    
    
    
    
    
%% display all p-values for each set of parameters
 
    
 function [] = plot_pval(par, values, plotpar)   
    
h1 = figure;                        % create first figure

n_cols=plotpar.n_cols;
n_rows=plotpar.n_rows;
n_runs=par.n_runs;

s = size(values,2);
s2= n_rows*n_cols/2;
sig = zeros(3,s);

 if (s > s2)
     error('Too many sets of parameters for #rows & #columns!');
 end


for a = 1:s
    
    if (plotpar.design == 'altn')
        a1 = a + floor((a-1)/n_cols)*n_cols;
        a2 = a1+n_cols;
    else
        a1 = a;
        a2 = a1+s2;
    end
    
    
    subplot(n_rows,n_cols,a1)
    
    
    bar([1:n_runs],values(a).p(1,:)), xlabel (values(a).str), axis ([0 n_runs+1 0 1 ]),
    hold on
    if plotpar.p_means
        line([0 n_runs+1],[values(a).mean(1) values(a).mean(1)], 'Color','b')
    end
    line([0 n_runs+1],[0.05 0.05], 'Color','r')
    
    if plotpar.suptext ==1
        suptext(values,a,n_runs,1,sig)
    end
    
    set(gca,'xtick',[])
    set(gca,'ytick',[0.2 0.4 0.6 0.8 1])
    
    subplot(n_rows,n_cols,a2)
    bar([1:n_runs],values(a).p(2,:),'FaceColor',[0.7 0.7 0.7]), xlabel (values(a).str), axis ([0 n_runs+1 0 1 ]),
    hold on
    if plotpar.p_means
        line([0 n_runs+1],[values(a).mean(2) values(a).mean(2)], 'Color','b')
    end
    line([0 n_runs+1],[0.05 0.05], 'Color','r')
    
    if plotpar.suptext ==1
        suptext(values,a,n_runs,2,sig)
    end
end

set(gca,'xtick',[])
set(gca,'ytick',[0.2 0.4 0.6 0.8 1])
h = annotation('textbox',[0.01 0.5 0.1 0.4]);
set(h,'String', plotpar.boxtext)


end

%% show significance results in p-value plot

function [sig] = suptext(values,a,n_runs,i,sig)

for r = 1:n_runs    
    
    if values(a).sign2(i,r) == 1
        text(r-0.2,0.9,'S','FontWeight','bold')
   
    else
        if values(a).sign(i,r) == 1
            text(r-0.2,0.9,'s')
        end
    end
    if values(a).instmix(i,r) == 1
        text(r-0.3,0.9,'IM','Color','r','FontWeight','bold')
    end  
    
end
end

%% create a textbox displaying all fixed parameters

function[boxtext] = make_text(par)
a = 0;
boxtext = {};
label = '';

% a = a+1;
% boxtext{a} = strcat('Param. gen. =',par.mode);

a = a+1;
boxtext{a} = strcat('Optim. Method =',par.opt_meth);


a = a+1;
a = a+1;
boxtext{a} = strcat('AR order=',sprintf('%02d',par.order));

a = a+1;
boxtext{a} ='';

a = a+1;
if size(par.eta_x,2) == 1
    boxtext{a} = strcat('eta_x=',sprintf('%1.1f',par.eta_x));
end

a = a+1;
if size(par.eta_y,2) == 1
    boxtext{a} = strcat('eta_y=',sprintf('%1.1f',par.eta_y));
end

a = a+1;
boxtext{a} ='';

a = a+1;
boxtext{a} = strcat('interact. delay=',sprintf('%02d',par.dt),' ms');

if size(par.u ,2) == 1
    a = a+1;
    boxtext{a} = strcat('predict. time u=', sprintf('%02d',par.u),' ms');
end

a = a+1;
boxtext{a} ='';

switch size(par.cpl,2) 
    
    case 1
        a = a+1;
        boxtext{a} = strcat('cpl. type:  ', par.cpl{1});
        a = a+1;
        boxtext{a} ='';
        a = a+1;
        boxtext{a} ='';
    case 2
        a = a+1;
        boxtext{a} = strcat('cpl. type:  ', par.cpl{1},', ',par.cpl{2});
        a = a+1;
        boxtext{a} ='';
        a = a+1;
        boxtext{a} ='';
    case 3
        a = a+1;
        boxtext{a} = 'cpl. type:  ';
        a = a+1;
        boxtext{a} = strcat(par.cpl{1},', ',par.cpl{2},', ',par.cpl{3});
        a = a+1;
        boxtext{a} ='';
    case 4
        a = a+1;
        boxtext{a} = 'cpl. type:  ';
        a = a+1;
        boxtext{a} = strcat(par.cpl{1},', ',par.cpl{2},', ',par.cpl{3},', ',par.cpl{4},', ');
        a = a+1;
        boxtext{a} ='';
end;








a = a+1;
boxtext{a} = strcat('sampling rate=',sprintf('%02d',par.fsample));
a = a+1;
boxtext{a} ='';

if size(par.nx,2) == 1
    a = a+1;
    boxtext{a} = strcat('source noise =',sprintf('%1.1f',par.nx));
end

if size(par.ny,2) == 1
    a = a+1;
    boxtext{a} = strcat('target noise =',sprintf('%1.1f',par.ny));
end

a = a+1;
boxtext{a} ='';

if size(par.n_runs,2) == 1
    a = a+1;
    boxtext{a} = strcat('#runs=',sprintf('%02d',par.n_runs));
end

if size(par.nT,2) == 1
    a = a+1;
    boxtext{a} = strcat('#Trials=',sprintf('%02d',par.nT));
end

if size(par.nS,2) == 1
    a = a+1;
    boxtext{a} = strcat('#Samples=',sprintf('%02d',par.nS));
end



a = a+1;
boxtext{a} ='';

if size(par.g ,2) == 1
    a = a+1;
    boxtext{a} = strcat('coupl. strength=',sprintf('%1.1f',par.g));
end

end

%% plot the results of significance tests

function [] = plot_sign(par, values, plotpar)

h2 = figure;    
s = size(values,2);
n = size(par.(plotpar.plotthis),2);
s_n = s/n;
f1 = 100/par.n_runs;

n_rows = plotpar.n_rows;
n_cols = plotpar.n_cols;

if ~plotpar.plot_shift
    n_rows = n_rows/2;
end

a = 0;
c = 0;
sig = zeros(s_n,n,2);
sig2= zeros(s_n,n,2);
im  = zeros(s_n,n,2);

xmin  = min(par.(plotpar.plotthis));
xmax  = max(par.(plotpar.plotthis));
xdiff = xmax - xmin;
xmin  = xmin - xdiff*0.1;
xmax  = xmax + xdiff*0.1;

if plotpar.plotthis == 'u'
    par.a_vert = par.a1;
    par.a_par  = par.a2;
    par.a_hor  = par.a3*par.a4*par.a5*par.a6*par.a7*par.a8;
    xlab = 'prediction time u in ms';    
end

if plotpar.plotthis == 'nx'
    par.a_vert = par.a1*par.a2;
    par.a_par  = par.a3;
    par.a_hor  = par.a4*par.a5*par.a6*par.a7*par.a8;
    xlab = 'rel. strength of source noise (a.u.)';
end

if plotpar.plotthis == 'nT'
    par.a_vert = par.a1*par.a2*par.a3*par.a4;
    par.a_par  = par.a5;
    par.a_hor  = par.a6*par.a7*par.a8;
    xlab = '#Trials per run';
end

if plotpar.plotthis == 'nS'
    par.a_vert = par.a1*par.a2*par.a3*par.a4*par.a5;
    par.a_par  = par.a6;
    par.a_hor  = par.a7*par.a8;
    xlab = '#Samples per Trial';
end

for nv = 1 : par.a_vert        
   for nc = 1 : par.a_par                                            % for all values of nx       
        for nh = 1:par.a_hor        
            
            a = a+1;
            b = nh + par.a_hor*c;     
            
            for i = 1:2                            
                %ass{a,1} = a;                                     
                %ass{a,2} = b;
                %ass{a,3} = values(a).str;    
                sig(b,nc,i)  = f1*sum(values(a).sign(i,:));         % significance
                sig2(b,nc,i) = f1*sum(values(a).sign2(i,:));        % significance after permutation test
                im(b,nc,i)   = f1*sum(values(a).instmix(i,:));      % significant shift test (lin. mixing or vol. conduction)               
            end       
        end     
   end
   c=c+1;
end

for a = 1:s_n
        for i = 1:1
            a_cpl = mod(a,par.a1);
            
            if a_cpl == 0
               a_cpl = par.a1
            end            
            
            if (plotpar.design == 'altn')
                a1 = a + floor((a-1)/n_cols)*n_cols;
                a2 = a1+n_cols;
            else
                a1 = a;
                a2 = a1+s2;
            end
                        
            tit1 = strcat('significant couplings');
            tit2 = strcat('significant shift tests');
            
              subplot(n_rows,n_cols,a1)

                plot(par.(plotpar.plotthis),sig2(a,:,1),'-bo','MarkerSize',6,'LineWidth',2), 
                hold on
                plot(par.(plotpar.plotthis),sig2(a,:,2),'-rs','MarkerSize',6,'LineWidth',2), xlabel (xlab,'FontSize',12), ylabel('in %'), axis ([xmin xmax -5 105]), title(tit1,'FontSize',16)
                line([xmin xmax],[  0   0],'Color','k','LineWidth',2)
                line([xmin xmax],[100 100],'Color','k','LineWidth',2)
                hold off
                legend('x->y','y->x',1)

            if plotpar.plot_shift

              subplot(n_rows,n_cols,a2)
              
                plot(par.(plotpar.plotthis),im(a,:,1),'-bo','MarkerSize',6,'LineWidth',2), 
                hold on
                plot(par.(plotpar.plotthis),im(a,:,2),'-rs','MarkerSize',6,'LineWidth',2), xlabel (xlab,'FontSize',12), ylabel('in %'), axis ([xmin xmax -5 105]), title(tit2,'FontSize',16)
                line([xmin xmax],[  0   0],'Color','k','LineWidth',2)
                line([xmin xmax],[100 100],'Color','k','LineWidth',2)
                hold off
                legend('x->y','y->x',1)
            end
        end
end

h = annotation('textbox',[0.01 0.45 0.08 0.35]);
set(h,'String', plotpar.boxtext)
plot_dim(par, values, plotpar)
end
    
%% plot dim and tau  

function [] = plot_dim(par, values, plotpar)

h3 = figure;    
s = size(values,2);
n = size(par.(plotpar.plotthis),2);
s_n = s/n;
f1 = 100/par.n_runs;

n_rows = plotpar.n_rows;
n_cols = plotpar.n_cols;

if ~plotpar.plot_shift
    n_rows = n_rows/2;
end

a = 0;
c = 0;
sig = zeros(s_n,n,2);
sig2= zeros(s_n,n,2);
im  = zeros(s_n,n,2);

xmin  = min(par.(plotpar.plotthis));
xmax  = max(par.(plotpar.plotthis));
xdiff = xmax - xmin;
xmin  = xmin - xdiff*0.1;
xmax  = xmax + xdiff*0.1;

if plotpar.plotthis == 'u'
    par.a_vert = par.a1;
    par.a_par  = par.a2;
    par.a_hor  = par.a3*par.a4*par.a5*par.a6*par.a7*par.a8;
    xlab = 'prediction time u in ms';    
end

if plotpar.plotthis == 'nx'
    par.a_vert = par.a1*par.a2;
    par.a_par  = par.a3;
    par.a_hor  = par.a4*par.a5*par.a6*par.a7*par.a8;
    xlab = 'rel. strength of source noise (a.u.)';
end

if plotpar.plotthis == 'nT'
    par.a_vert = par.a1*par.a2*par.a3*par.a4;
    par.a_par  = par.a5;
    par.a_hor  = par.a6*par.a7*par.a8;
    xlab = '#Trials per run';
end

if plotpar.plotthis == 'nS'
    par.a_vert = par.a1*par.a2*par.a3*par.a4*par.a5;
    par.a_par  = par.a6;
    par.a_hor  = par.a7*par.a8;
    xlab = '#Samples per Trial';
end

for nv = 1 : par.a_vert        
   for nc = 1 : par.a_par                                            % for all values of nx       
        for nh = 1:par.a_hor        
            
            a = a+1;
            b = nh + par.a_hor*c;     
            
                                 
                mean_dim(b,nc)  = values(a).mean_dim;         
                mean_tau(b,nc)  = values(a).mean_tau;  
                
                var_dim(b,nc)  = values(a).var_dim;         
                var_tau(b,nc)  = values(a).var_tau; 
                   
        end     
   end
   c=c+1;
end

for a = 1:s_n
        for i = 1:1
            a_cpl = mod(a,par.a1);
            
            if a_cpl == 0
               a_cpl = par.a1
            end            
            
            if (plotpar.design == 'altn')
                a1 = a + floor((a-1)/n_cols)*n_cols;
                a2 = a1+n_cols;
            else
                a1 = a;
                a2 = a1+s2;
            end
                        
            tit1 = strcat('chosen dimension');
            tit2 = strcat('chosen tau');
            
              subplot(n_rows,n_cols,a1)

                errorbar(par.(plotpar.plotthis),mean_dim(a,:),var_dim(a,:),'-bo','MarkerSize',6,'LineWidth',2), axis ([xmin xmax -1 11]), title(tit1,'FontSize',16)
                hold on
%                 plot(par.(plotpar.plotthis),sig2(a,:,2),'-rs','MarkerSize',6,'LineWidth',2), xlabel (xlab,'FontSize',12), ylabel('in %'), 
%                 line([xmin xmax],[  0   0],'Color','k','LineWidth',2)
%                 line([xmin xmax],[100 100],'Color','k','LineWidth',2)
%                 hold off
                legend('x->y','y->x',1)

            if plotpar.plot_shift

              subplot(n_rows,n_cols,a2)
              
                errorbar(par.(plotpar.plotthis),mean_tau(a,:),var_tau(a,:),'-bo','MarkerSize',6,'LineWidth',2), axis ([xmin xmax 0.5 2.5]), title(tit2,'FontSize',16)
                hold on
%                 plot(par.(plotpar.plotthis),im(a,:,2),'-rs','MarkerSize',6,'LineWidth',2), xlabel (xlab,'FontSize',12), ylabel('in %'), 
%                 line([xmin xmax],[  0   0],'Color','k','LineWidth',2)
%                 line([xmin xmax],[100 100],'Color','k','LineWidth',2)
                 hold off
                legend('x->y','y->x',1)
            end
        end
end

h = annotation('textbox',[0.01 0.45 0.08 0.35]);
set(h,'String', plotpar.boxtext)





end


% 
% function [] = suptext_s(values)
% 
% for r = 1:n_runs    
%     
%     if values(a).sign2(i,r) == 1
%         text(r-0.2,0.9,'S','FontWeight','bold')
%    
%     else
%         if values(a).sign(i,r) == 1
%             text(r-0.2,0.9,'s')
%         end
%     end
%     if values(a).instmix(i,r) == 1
%         text(r-0.3,0.9,'IM','Color','r','FontWeight','bold')
%     end  
%     
% end
% end